@@ -330,7 +330,7 @@ class CLI(cl1.CLI):
 			# generate a key.
 			passphrase = self.get_passphrase(required=False)
 			if passphrase in [False, None, "", "null", "None", "none"]: passphrase = None
-			response = ssht00ls.key.generate(
+			response = ssht00ls.keys.generate(
 				path=self.arguments.get("--path", chapter="keys", mode="--generate"), 
 				passphrase=passphrase, 
 				comment=self.arguments.get("--comment", chapter="keys", mode="--generate"),)
