@@ -2,14 +2,14 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-from ssht00ls.classes.config import version
+from ssht00ls.classes.config import version, SOURCE_PATH
 from ssht00ls.classes import utils
 from ssht00ls.classes.installation import installation
 from ssht00ls.classes.sshd import sshd
 from ssht00ls.classes.sshfs import sshfs
 from ssht00ls.classes.scp import scp
 from ssht00ls.classes.agent import agent
-from ssht00ls.classes.key import key
+from ssht00ls.classes.keys import keys
 from ssht00ls.classes.connections import connections
 from ssht00ls.classes.smart_cards import smart_cards, SmartCard
 from ssht00ls.classes.aliases import aliases
