@@ -102,7 +102,7 @@ class Agent(object):
 			})
 			if not response["success"]: return response
 		else:
-			if not os.path.exists(path):
+			if not Files.exists(path):
 				return r3sponse.error(f"Key path [{path}] does not exist.")
 
 		# check agent connection.
@@ -276,14 +276,14 @@ class Agent(object):
 		if not response["success"]: return response
 
 		# checks.
-		if not raw and not os.path.exists(public_key):
+		if not raw and not Files.exists(public_key):
 			return r3sponse.error(f"Public key path [{public_key}] does not exist.")
 
 		# load public key.
 		if not raw:
 			try:
-				public_key = utils.__load_file__(public_key)
-			except:
+				public_key = Files.load(public_key)
+			except FileNotFoundError:
 				return r3sponse.error(f"Failed to load public key path [{public_key}].")
 
 		# retrieve id from public key.
