@@ -101,13 +101,15 @@ if CHECKS and not cl1.arguments_present("--reset-cache"):
 
 	# check lib.
 	if not Files.exists(f"{SOURCE_PATH}/lib"):
-		print("Downloading ssht00ls library.")
-		os.system(f"rm -fr /tmp/ssht00ls && git clone https://github.com/vandenberghinc/ssht00ls /tmp/ssht00ls && cp -r /tmp/ssht00ls/ssht00ls/lib {SOURCE_PATH}/lib")
+		r3sponse.log("Downloading the ssht00ls library.")
+		os.system(f"rm -fr /tmp/ssht00ls && git clone https://github.com/vandenberghinc/ssht00ls /tmp/ssht00ls && rsync -azq /tmp/ssht00ls/ssht00ls/lib/ {SOURCE_PATH}/lib/")
 
 	# check usr lib.
 	if not Files.exists("/usr/local/lib/ssht00ls"):
-		print("Installing ssht00ls into system library.")
-		os.system(f"rsync -azP {SOURCE_PATH}/ /usr/local/lib/ssht00ls")
+		r3sponse.log(f"{syst3m.color.orange}Root permission{syst3m.color.end} required to install the ssht00ls system library.")
+		os.system(f" sudo rsync -azq --delete {SOURCE_PATH}/ /usr/local/lib/ssht00ls")
+		Files.chown("/usr/local/lib/ssht00ls", owner=syst3m.defaults.vars.owner, group=syst3m.defaults.vars.group, sudo=True, recursive=True)
+		Files.chmod("/usr/local/lib/ssht00ls", permission=770, sudo=True, recursive=True)
 
 	# database.
 	for dir, permission in [
@@ -240,7 +242,6 @@ if CHECKS and not cl1.arguments_present("--reset-cache"):
 			if not response["success"]: 
 				r3sponse.log(error=f"Encoutered an error while activating the encrypted cache: {response['error']}", json=cl1.arguments_present(["--json", "-j"]))
 				sys.exit(1)
-			PASSPHRASES = ENCRYPTED_DATABASE.load("passphrases")
 
 			#
 
