@@ -97,19 +97,19 @@ def pull(
 		#if not response["success"]: return response
 		response = ssh.utils.test_ssht00ls(alias=alias, accept_new_host_keys=accept_new_host_keys)
 		if not response.success: return response
-		response = ssh.utils.test_ssh_path(alias=alias, path=remote, accept_new_host_keys=accept_new_host_keys)
+		response = ssh.utils.test_path(alias=alias, path=remote, accept_new_host_keys=accept_new_host_keys)
 		if not response.success: return response
 
 		# dir.
 		if directory == None: 
-			response = ssh.utils.test_ssh_dir(alias=alias, path=remote, accept_new_host_keys=accept_new_host_keys)
+			response = ssh.utils.test_dir(alias=alias, path=remote, accept_new_host_keys=accept_new_host_keys)
 			if not response.success and "not a directory" not in response.error: return response
 			elif response.success:
 				directory = True
 			else: directory = False
 			tested = True
 		elif directory:
-			response = ssh.utils.test_ssh_dir(alias=alias, path=remote, accept_new_host_keys=accept_new_host_keys)
+			response = ssh.utils.test_dir(alias=alias, path=remote, accept_new_host_keys=accept_new_host_keys)
 			if not response.success: return response
 			tested = True
 
@@ -202,7 +202,7 @@ def push(
 		#if not response["success"]: return response
 		response = ssh.utils.test_ssht00ls(alias=alias, accept_new_host_keys=accept_new_host_keys)
 		if not response.success: return response
-		response = ssh.utils.test_ssh_path(alias=alias, path=FilePath(remote).base(), accept_new_host_keys=accept_new_host_keys)
+		response = ssh.utils.test_path(alias=alias, path=FilePath(remote).base(), accept_new_host_keys=accept_new_host_keys)
 		if not response.success: return response
 
 		# dir.
@@ -213,7 +213,7 @@ def push(
 	# check remote base.
 	# must be excluded from the checks == False.
 	base = FilePath(remote).base(back=1)
-	response = ssh.utils.test_ssh_dir(alias=alias, path=base, accept_new_host_keys=accept_new_host_keys, create=True, checks=False)
+	response = ssh.utils.test_dir(alias=alias, path=base, accept_new_host_keys=accept_new_host_keys, create=True, checks=False)
 	if not response.success: return response
 	if response.created and log_level >= 3: print(f"Created remote directory {base}.")
 
